Enum style_traits::values::specified::AllowedNumericType
[−]
[src]
#[repr(u8)]pub enum AllowedNumericType { All, NonNegative, AtLeastOne, }
Whether to allow negative lengths or not.
Variants
AllAllow all kind of numeric values.
NonNegativeAllow only non-negative numeric values.
AtLeastOneAllow only numeric values greater or equal to 1.0.
Methods
impl AllowedNumericType[src]
pub fn is_ok(&self, parsing_mode: ParsingMode, val: f32) -> bool[src]
Whether the value fits the rules of this numeric type.
pub fn clamp(&self, val: f32) -> f32[src]
Clamp the value following the rules of this numeric type.